@@ -6,26 +6,21 @@ from autogalaxy.pipeline.phase.dataset import analysis as ag_analysis
 from autolens.fit import fit
 from autolens.pipeline import visualizer
 from autolens.pipeline.phase.dataset import analysis as analysis_dataset
+from autogalaxy.pipeline.phase.imaging.analysis import Attributes as AgAttributes
 
 import copy
 
 
 class Analysis(ag_analysis.Analysis, analysis_dataset.Analysis):
     def __init__(
-        self,
-        masked_imaging,
-        settings,
-        cosmology,
-        image_path=None,
-        results=None,
-        log_likelihood_cap=None,
+        self, masked_imaging, settings, cosmology, image_path=None, results=None
     ):
 
         super().__init__(
+            masked_dataset=masked_imaging,
             settings=settings,
             cosmology=cosmology,
             results=results,
-            log_likelihood_cap=log_likelihood_cap,
         )
 
         self.visualizer = visualizer.PhaseImagingVisualizer(
@@ -37,8 +32,6 @@ class Analysis(ag_analysis.Analysis, analysis_dataset.Analysis):
             hyper_model_image=self.hyper_model_image,
         )
 
-        self.masked_dataset = masked_imaging
-
     @property
     def masked_imaging(self):
         return self.masked_dataset
@@ -202,3 +195,24 @@ class Analysis(ag_analysis.Analysis, analysis_dataset.Analysis):
                 max_log_evidence=fit.log_evidence,
                 during_analysis=during_analysis,
             )
+
+    def make_attributes(self):
+        return Attributes(
+            cosmology=self.cosmology,
+            positions=self.masked_dataset.positions,
+            hyper_model_image=self.hyper_model_image,
+            hyper_galaxy_image_path_dict=self.hyper_galaxy_image_path_dict,
+        )
+
+
+class Attributes(AgAttributes):
+    def __init__(
+        self, cosmology, positions, hyper_model_image, hyper_galaxy_image_path_dict
+    ):
+        super().__init__(
+            cosmology=cosmology,
+            hyper_model_image=hyper_model_image,
+            hyper_galaxy_image_path_dict=hyper_galaxy_image_path_dict,
+        )
+
+        self.positions = positions
