@@ -11,7 +11,7 @@ from autolens.plot import ray_tracing_plots, fit_imaging_plots, fit_interferomet
 
 
 def setting(section, name):
-    return conf.instance.visualize_plots.get(section, name, bool)
+    return conf.instance["visualize"]["plots"][section][name]
 
 
 def plot_setting(section, name):
