@@ -4,29 +4,30 @@ from test_autolens.integration.tests.imaging import runner
 
 test_type = "lens__source_inversion"
 test_name = "lens_mass__source_adaptive_brightness__stochastic"
-data_name = "lens_sie__source_smooth"
+dataset_name = "lens_sie__source_smooth"
 instrument = "euclid"
 
 
 def make_pipeline(name, path_prefix, search=af.DynestyStatic()):
 
     phase1 = al.PhaseImaging(
-        phase_name="phase_1",
-        path_prefix=path_prefix,
+        search=af.DynestyStatic(
+            name="phase[1]", n_live_points=40, evidence_tolerance=10.0
+        ),
         galaxies=dict(
             lens=al.GalaxyModel(redshift=0.5, mass=al.mp.EllipticalIsothermal),
             source=al.GalaxyModel(redshift=1.0, light=al.lp.EllipticalSersic),
         ),
-        search=af.DynestyStatic(n_live_points=40, evidence_tolerance=10.0),
     )
 
     phase1 = phase1.extend_with_multiple_hyper_phases(
-        setup_hyper=al.SetupPipeline(), include_inversion=False
+        setup_hyper=al.SetupHyper(), include_inversion=False
     )
 
     phase2 = al.PhaseImaging(
-        phase_name="phase_2",
-        path_prefix=path_prefix,
+        search=af.DynestyStatic(
+            name="phase[2]", n_live_points=40, evidence_tolerance=50.0
+        ),
         galaxies=dict(
             lens=al.GalaxyModel(
                 redshift=0.5, mass=phase1.result.instance.galaxies.lens.mass
@@ -37,17 +38,16 @@ def make_pipeline(name, path_prefix, search=af.DynestyStatic()):
                 regularization=al.reg.AdaptiveBrightness,
             ),
         ),
-        search=af.DynestyStatic(n_live_points=40),
     )
 
     phase2 = phase2.extend_with_stochastic_phase(
-        stochastic_search=af.DynestyStatic(n_live_points=40, evidence_tolerance=10000.0)
+        stochastic_search=af.DynestyStatic(n_live_points=40, evidence_tolerance=1.0)
     )
 
-    return al.PipelineDataset(name, phase1, phase2)
+    return al.PipelineDataset(name, path_prefix, phase1, phase2)
 
 
-if ``.ame__ == "__main__":
+if __name__ == "__main__":
     import sys
 
     runner.run(sys.modules[__name__])
