@@ -4,7 +4,7 @@ from test_autolens.integration.tests.imaging import runner
 
 test_type = "phase_features"
 test_name = "positions__offset_centre"
-data_name = "lens_sis__source_smooth__offset_centre"
+dataset_name = "lens_sis__source_smooth__offset_centre"
 instrument = "vro"
 
 
@@ -18,7 +18,7 @@ def make_pipeline(name, path_prefix, search=af.DynestyStatic()):
             self.galaxies.source.light.centre_1 = af.GaussianPrior(mean=4.0, sigma=0.1)
 
     phase1 = LensPhase(
-        phase_name="phase_1",
+        name="phase[1]",
         path_prefix=path_prefix,
         galaxies=dict(
             lens=al.GalaxyModel(redshift=0.5, mass=al.mp.SphericalIsothermal),
@@ -32,7 +32,7 @@ def make_pipeline(name, path_prefix, search=af.DynestyStatic()):
     phase1.search.n_live_points = 30
     phase1.search.facc = 0.8
 
-    return al.PipelineDataset(name, phase1)
+    return al.PipelineDataset(name, path_prefix, phase1)
 
 
 if __name__ == "__main__":
