@@ -18,7 +18,9 @@ for instrument in ["hst_up"]:
     print()
 
     imaging = instrument_util.load_test_imaging(
-        data_name="lens_sie__source_smooth", instrument=instrument, psf_shape_2d=(3, 3)
+        dataset_name="lens_sie__source_smooth",
+        instrument=instrument,
+        psf_shape_2d=(3, 3),
     )
     mask = al.Mask2D.circular_annular(
         shape=imaging.shape_2d,
