@@ -31,7 +31,7 @@ pixelization = al.pix.VoronoiBrightnessImage(pixels=pixels)
 for instrument in ["euclid", "hst", "hst_up"]:  # , 'ao']:
 
     imaging = instrument_util.load_test_imaging(
-        data_name="lens_sie__source_smooth", instrument=instrument
+        dataset_name="lens_sie__source_smooth", instrument=instrument
     )
 
     mask = al.Mask2D.circular(
@@ -121,9 +121,8 @@ for instrument in ["euclid", "hst", "hst_up"]:  # , 'ao']:
 
     start = time.time()
     for i in range(repeats):
-        curvature_matrix = al.util.inversion.curvature_matrix_via_blurred_mapping_matrix_from(
-            blurred_mapping_matrix=blurred_mapping_matrix,
-            noise_map=masked_imaging.noise_map,
+        curvature_matrix = al.util.inversion.curvature_matrix_via_mapping_matrix_from(
+            mapping_matrix=blurred_mapping_matrix, noise_map=masked_imaging.noise_map
         )
     diff = time.time() - start
     print("Time to compute curvature matrix = {}".format(diff / repeats))
@@ -144,6 +143,16 @@ for instrument in ["euclid", "hst", "hst_up"]:  # , 'ao']:
     diff = time.time() - start
     print("Time to compute curvature reguarization Matrix = {}".format(diff / repeats))
 
+    start = time.time()
+    for i in range(repeats):
+        preconditioner_matrix = al.util.inversion.preconditioner_matrix_via_mapping_matrix_from(
+            mapping_matrix=mapping_matrix,
+            preconditioner_noise_normalization=1.0,
+            regularization_matrix=regularization_matrix,
+        )
+    diff = time.time() - start
+    print("Time to compute preconditioner matrix = {}".format(diff / repeats))
+
     start = time.time()
     for i in range(repeats):
         reconstruction = np.linalg.solve(curvature_reg_matrix, data_vector)
